@@ -19,7 +19,7 @@ def docker_image_name(pyver, hgver, prebuilt_images):
         suffix = f':hg-{hgver}'
     else:
         suffix = ''
-    return f'octobus/ci-py{pyver}-hgext3rd' + suffix
+    return f'registry.heptapod.net/mercurial/ci-images/py{pyver}-hgext3rd' + suffix
 
 
 def gen_install_apt_dependencies(pyver, extra=[]):
@@ -63,10 +63,9 @@ def thg_make_command(target, pyver):
 
 
 def gen_gitlab_ci_yml():
-    with urllib.request.urlopen(
-        'https://index.docker.io/v1/repositories/octobus/ci-py3-hgext3rd/tags'
-    ) as r:
-        prebuilt_images = [t['name'] for t in json.load(r)]
+    # This was querying https://index.docker.io/v1/repositories/octobus/ci-py3-hgext3rd/tags,
+    # which hasn't been maintained.
+    prebuilt_images = ['latest']
 
     hg_releases = []
     for hgver in hgversion.testedwith.decode().split():
@@ -105,9 +104,9 @@ def gen_gitlab_ci_yml():
                 thg_make_command('local', 3),
                 # The following is a workaround for pytype's lack of support for
                 # custom pyi files (https://github.com/google/pytype/issues/483).
-                'ln -s `pwd`/contrib/typehints/* '
+                'ln -sf `pwd`/contrib/typehints/* '
                 '`python3 -c "import pytype; '
-                'print(pytype.__path__[0])"`/typeshed/third_party/3/',
+                'print(pytype.__path__[0])"`/typeshed/stubs/',
                 thg_make_command('pytype', 3),
             ],
             'allow_failure': True,
