@@ -99,6 +99,9 @@ def build_py2(
         source_dir / 'contrib' / 'packaging' / 'venv_py2' / 'requirements.txt'
     )
 
+    if os.name == 'nt':
+        requirements_txt = requirements_txt.parent / 'requirements_win32.txt'
+
     subprocess.run([
         str(venv_pip),
         "install",
@@ -107,15 +110,6 @@ def build_py2(
         "--disable-pip-version-check",
     ], check=True)
 
-    if os.name == 'nt':
-        subprocess.run([
-            str(venv_pip),
-            "install",
-            "-r",
-            str(requirements_txt.parent / 'requirements_win32.txt'),
-            "--disable-pip-version-check",
-        ], check=True)
-
     env = _get_msvc2017_env(vc_x64)
     env["CL"] = "/MP"  # Enable multiprocessor builds
 
