@@ -75,8 +75,8 @@ if os.name == 'nt' and getattr(sys, 'frozen', False):
     _mod = __import__(QT_API, globals(), locals(), ['QtSvg', 'QtXml'])
     _mod.QtSvg.__name__, _mod.QtXml.__name__  # no demandimport
 
-if PYQT_VERSION < 0x40705 or QT_VERSION < 0x40600:
-    sys.stderr.write('TortoiseHg requires at least Qt 4.6 and PyQt 4.7.5\n')
+if PYQT_VERSION < 0x50000 or QT_VERSION < 0x50000:
+    sys.stderr.write('TortoiseHg requires at least Qt 5.0 and PyQt 5.0\n')
     sys.stderr.write('You have Qt %s and PyQt %s\n' %
                      (QT_VERSION_STR, PYQT_VERSION_STR))
     sys.exit(-1)
@@ -237,7 +237,7 @@ class ExceptionCatcher(QObject):
 
         def _releaseWakeup(self):
             self._wakeupsn.setEnabled(False)
-            rfd = self._wakeupsn.socket()
+            rfd = int(self._wakeupsn.socket())
             wfd = signal.set_wakeup_fd(self._origwakeupfd)
             self._origwakeupfd = -1
             os.close(rfd)
@@ -421,24 +421,13 @@ class QtRunner(QObject):
 
         QSettings.setDefaultFormat(QSettings.IniFormat)
 
-        # fixes font placement on OSX 10.9 with QT <= 4.8.5
-        # see QTBUG-32789 (https://bugreports.qt-project.org/browse/QTBUG-32789)
-        if sys.platform == 'darwin' and QT_VERSION <= 0x040805:
-            version = platform.mac_ver()[0]
-            version = '.'.join(version.split('.')[:2])
-            if version == '10.9':
-                # needs to replace the font created in the constructor of
-                # QApplication, which is invalid use of QFont but works on Mac
-                QFont.insertSubstitution('.Lucida Grande UI', 'Lucida Grande')
-
         self._ui = ui
         self._config = hgconfig.HgConfig(ui)
         self._mainapp = QApplication(sys.argv)
 
-        if QT_VERSION >= 0x50000:
-            self._mainapp.setAttribute(Qt.AA_UseHighDpiPixmaps, True)
-            if sys.platform == 'darwin':
-                self._mainapp.setAttribute(Qt.AA_DontShowIconsInMenus, True)
+        self._mainapp.setAttribute(Qt.AA_UseHighDpiPixmaps, True)
+        if sys.platform == 'darwin':
+            self._mainapp.setAttribute(Qt.AA_DontShowIconsInMenus, True)
 
         self._exccatcher = ExceptionCatcher(ui, self._mainapp, self)
         self._gc = GarbageCollector(ui, self)
