@@ -64,7 +64,6 @@ from .qtgui import (
 from mercurial import (
     error,
     pycompat,
-    scmutil,
 )
 
 from ..util import hglib
@@ -132,7 +131,8 @@ class HgRepoView(QTableView):
         self.setSelectionBehavior(QAbstractItemView.SelectRows)
 
         self.doubleClicked.connect(self.revActivated)
-        self.clicked.connect(self.revClicked)
+        if repoagent.configBool('tortoisehg', 'copy_hash_selection'):
+            self.clicked.connect(self._copyHashToSelection)
 
     @property
     def repo(self):
@@ -322,7 +322,7 @@ class HgRepoView(QTableView):
     def context(self, rev):
         return self.repo[rev]
 
-    def revClicked(self, index):
+    def _copyHashToSelection(self, index):
         rev = self.revFromindex(index)
         if rev is not None:
             clip = QApplication.clipboard()
@@ -411,7 +411,7 @@ class HgRepoView(QTableView):
 
         try:
             # look for a mercurial commit hash
-            return scmutil.revsymbol(self.repo, symbolic_rev).rev()
+            return hglib.revsymbol(self.repo, symbolic_rev).rev()
         except error.RepoError:
             if b'hggit' not in self.repo.extensions():
                 # hg-git is not installed, do not try doing a gitnode() lookup
@@ -566,11 +566,11 @@ class GraphDelegate(QStyledItemDelegate):
         self._rowheight = 16  # updated to the actual height on paint()
 
     def _col2x(self, col):
-        maxradius = max(self._rowheight / 2, 1)
+        maxradius = max(self._rowheight // 2, 1)
         return maxradius * (col + 1)
 
     def _colcount(self, width):
-        maxradius = max(self._rowheight / 2, 1)
+        maxradius = max(self._rowheight // 2, 1)
         return (width + maxradius - 1) // maxradius
 
     def _dotradius(self):
@@ -595,7 +595,7 @@ class GraphDelegate(QStyledItemDelegate):
 
     def _drawEdges(self, painter, index, gnode, visibleend):
         h = self._rowheight
-        dot_y = h / 2
+        dot_y = h // 2
 
         def isactive(e):
             m = index.model()
@@ -605,9 +605,9 @@ class GraphDelegate(QStyledItemDelegate):
 
         for y1, y4, lines in ((dot_y, dot_y + h, gnode.bottomlines),
                               (dot_y - h, dot_y, gnode.toplines)):
-            y2 = y1 + 1 * (y4 - y1)/4
-            ymid = (y1 + y4)/2
-            y3 = y1 + 3 * (y4 - y1)/4
+            y2 = y1 + 1 * (y4 - y1) // 4
+            ymid = (y1 + y4) // 2
+            y3 = y1 + 3 * (y4 - y1) // 4
 
             # omit invisible lines
             lines = [((start, end), e) for (start, end), e in lines
@@ -633,7 +633,7 @@ class GraphDelegate(QStyledItemDelegate):
                     path.moveTo(x1, y1)
                     path.cubicTo(x1, y2,
                                  x1, y2,
-                                 (x1 + x2) / 2, ymid)
+                                 (x1 + x2) // 2, ymid)
                     path.cubicTo(x2, y3,
                                  x2, y3,
                                  x2, y4)
@@ -664,7 +664,7 @@ class GraphDelegate(QStyledItemDelegate):
         painter.setPen(pen)
 
         centre_x = self._col2x(gnode.x)
-        centre_y = self._rowheight / 2
+        centre_y = self._rowheight // 2
 
         def circle(r):
             rect = QRectF(centre_x - r,
